==> ath1121501.db_3.2.2.tar.gz: ath1121501.db/man/ath1121501GO.Rd <==
\name{ath1121501GO}
\alias{ath1121501GO}
\title{Map between Manufacturer IDs and Gene Ontology (GO)}
\description{
  ath1121501GO is an R object that provides mappings between
  manufacturer identifiers and the GO identifiers that they are 
  directly associated with. 
}
\details{
  Each Entrez Gene identifier is mapped to a list of lists.  The names on
  the outer list are GO identifiers.  Each inner list consists of three
  named elements: GOID, Ontology, and Evidence.

  The GOID element matches the GO identifier named in the outer list and is
  included for convenience when processing the data using 'lapply'.
  
  The Ontology element indicates which of the three Gene Ontology
  categories this identifier belongs to.  The categories are
  biological process (BP), cellular component (CC), and molecular
  function (MF).

  The Evidence element contains a code indicating what kind of evidence
  supports the association of the GO identifier to the Entrez Gene
  id. Some of the evidence codes in use include:

  IMP: inferred from mutant phenotype  

  IGI: inferred from genetic interaction

  IPI: inferred from physical interaction  

  ISS: inferred from sequence similarity 

  IDA: inferred from direct assay  

  IEP: inferred from expression pattern  

  IEA: inferred from electronic annotation  

  TAS: traceable author statement  

  NAS: non-traceable author statement  

  ND: no biological data available  

  IC: inferred by curator

  A more complete listing of evidence codes can be found at:

  \url{http://www.geneontology.org/GO.evidence.shtml}
  
  
  Mappings between probe identifiers and GO information were obtained through
  their mappings to Entrez Gene identifiers. NAs are assigned to probe identifiers
  that can not be mapped to any Gene Ontology information. Mappings
  between Gene Ontology identifiers an Gene Ontology terms and other information
  are available in a separate data package named GO.
  
  Mappings were based on data provided by: Gene Ontology  
  ftp://ftp.geneontology.org/pub/go/godatabase/archive/latest-lite/  
  With a date stamp from the source of: 20150919

}

\examples{
        x <- ath1121501GO
        # Get the probe identifiers that are mapped to a GO ID
        mapped_probes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_probes])
        if(length(xx) > 0) {
            # Try the firest one
            got <- xx[[1]]           
            got[[1]][["GOID"]]
            got[[1]][["Ontology"]]
            got[[1]][["Evidence"]]

        }
}
\keyword{datasets}

==> ath1121501.db_3.13.0.tar.gz: ath1121501.db/man/ath1121501GO.Rd <==
\name{ath1121501GO}
\alias{ath1121501GO}
\title{Map between Manufacturer IDs and Gene Ontology (GO)}
\description{
  ath1121501GO is an R object that provides mappings between
  manufacturer identifiers and the GO identifiers that they are 
  directly associated with. 
}
\details{
  Each Entrez Gene identifier is mapped to a list of lists.  The names on
  the outer list are GO identifiers.  Each inner list consists of three
  named elements: GOID, Ontology, and Evidence.

  The GOID element matches the GO identifier named in the outer list and is
  included for convenience when processing the data using 'lapply'.
  
  The Ontology element indicates which of the three Gene Ontology
  categories this identifier belongs to.  The categories are
  biological process (BP), cellular component (CC), and molecular
  function (MF).

  The Evidence element contains a code indicating what kind of evidence
  supports the association of the GO identifier to the Entrez Gene
  id. Some of the evidence codes in use include:

  IMP: inferred from mutant phenotype  

  IGI: inferred from genetic interaction

  IPI: inferred from physical interaction  

  ISS: inferred from sequence similarity 

  IDA: inferred from direct assay  

  IEP: inferred from expression pattern  

  IEA: inferred from electronic annotation  

  TAS: traceable author statement  

  NAS: non-traceable author statement  

  ND: no biological data available  

  IC: inferred by curator

  A more complete listing of evidence codes can be found at:

  \url{http://www.geneontology.org/GO.evidence.shtml}
  
  
  Mappings between probe identifiers and GO information were obtained through
  their mappings to Entrez Gene identifiers. NAs are assigned to probe identifiers
  that can not be mapped to any Gene Ontology information. Mappings
  between Gene Ontology identifiers an Gene Ontology terms and other information
  are available in a separate data package named GO.
  
  Mappings were based on data provided by: Gene Ontology  
  http://current.geneontology.org/ontology/go-basic.obo  
  With a date stamp from the source of: 2021-02-01

}

\seealso{
  \itemize{
    \item \code{\link[AnnotationDbi]{AnnotationDb-class}} for use of
          the \code{select()} interface.
  }
}

\examples{
## select() interface:
## Objects in this package can be accessed using the select() interface
## from the AnnotationDbi package. See ?select for details.

## Bimap interface:
x <- ath1121501GO
# Get the probe identifiers that are mapped to a GO ID
mapped_probes <- mappedkeys(x)
# Convert to a list
xx <- as.list(x[mapped_probes])
if(length(xx) > 0) {
    # Try the firest one
    got <- xx[[1]]           
    got[[1]][["GOID"]]
    got[[1]][["Ontology"]]
    got[[1]][["Evidence"]]

}
}
\keyword{datasets}
